{% from "functions.html" import index_hero %}
{% if domain != None %}
    {% set title = domain.split(':')[1] %}
    {% set title = title[2:] %}
{% else %}
{% set title = "urlshrink" %}
{% endif %}
<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <title>{{ title }}</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/bulma/0.9.2/css/bulma.min.css" rel="stylesheet">
    <style>
        .center {
          margin : 0 auto;
          text-align : center;
        }
    </style>
  </head>
  <body>
    {{ index_hero(title) }}
    {% block body %}{% endblock %}
  </body>
</html>